#
# spec file for package galculator
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           galculator
Version:        2.1.4
Release:        3.21
Summary:        A GTK 3 based calculator
License:        GPL-2.0-or-later
Group:          System/GUI/GNOME
URL:            http://galculator.mnim.org/
Source0:        http://galculator.mnim.org/downloads/%{name}-%{version}.tar.bz2
BuildRequires:  flex
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gtk+-3.0)
Recommends:     %{name}-lang

%description
galculator is a GTK 3 based calculator with ordinary notation/reverse
polish notation (RPN), a formula entry mode, different number bases
(DEC, HEX, OCT, BIN) and different units of angular measure (DEG, RAD, GRAD).
It supports quad-precision floating point and 112-bit binary arithmetic.

%lang_package

%prep
%setup -q

%build
# workaround for GCC10 build failure
export CFLAGS="%(echo %{optflags}) -fcommon"
export CXXFLAGS="$CFLAGS"
%configure
make %{?_smp_mflags}

%install
%make_install
%if 0%{?suse_version} == 1310
rm  %{buildroot}/%{_datadir}/appdata/galculator.appdata.xml
%endif
%suse_update_desktop_file -r %{name} GTK Utility Calculator
%find_lang %{name}

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%doc AUTHORS ChangeLog COPYING NEWS README THANKS doc/shortcuts
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/*
%if 0%{?suse_version} > 1310
%dir %{_datadir}/appdata
%{_datadir}/appdata/galculator.appdata.xml
%endif
%{_datadir}/icons/hicolor/*/*/%{name}.*
%{_datadir}/pixmaps/%{name}.*
%{_mandir}/man1/%{name}.1%{ext_man}

%files lang -f %{name}.lang

%changelog
* Thu Jun 11 2020 Paolo Stivanin <info@paolostivanin.com>
- Add -fcommon to allow building against GCC10
* Sun Dec 29 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Removed Provide and obsolete mate-calc. Galculator is NOT a replacement
  for mate-calc which is its own project.
* Mon Jan  1 2018 avindra@opensuse.org
- use new upstream urls
- cleanup with spec-cleaner
- link against gtk 3 (instead of 2)
* Fri Oct 16 2015 trcs@gmx.com
- new upstream version 2.1.4
  * adding a fresh "tx pull" of translations
  * adding an appdata file
  * in ui.c::set_all_dispctrl_buttons_property check for
    table_children != NULL (fixes sf.net bug #107)
  * *.c: all dynamic memory allocation and free'ing is done via
    glib now.
  * Changed default background color for the display to white.
  * In callbacks.c and general_functions.c, team up every
    gtk_check_menu_item_set_active with a gtk_check_menu_item_toggled.
    See also 2014-01-08 and sf.net bug #99. (fixes sf.net bug #105)
  * translations are now served through transifex
  * set_basic_object_data/set_scientific_object_data make structs
    static (fixes sf.net bug #104)
- updated description
* Sun Jun 28 2015 p.drouand@gmail.com
- Provide and obsolete mate-calc; galculator has replaced
  mate-calc in Mate 1.10
* Fri Mar 14 2014 andrea@opensuse.org
- new upstream verson 2.1.3
  * Added Spanish tranlsation
  * Fixed segfault introduced in r134
  * Updated Turkish translations
  * Fixing result string corruption when toggling sign
  * Emitting signal in apply_preferences so that menu gets
  hidden after a restart again
  * added Hungarian translation
  * rpn_stack_list when pasting
* Thu Mar  6 2014 trcs@gmx.com
- Added Spanish translation.
* Mon Apr 29 2013 andrea@opensuse.org
- new upstream version 2.1.2
  * This release fixes a handful of bugs:
    a minor flaw in the build process and
    migrates some deprecated GUI elements to recent GTK3
  * Added Lithuanian Translation.
* Sat Mar  2 2013 lazy.kent@opensuse.org
- Update to 2.1.
  * Adds support for quad-precision floating point and up to
    112-bit binary arithmetic on systems with libquadmath.
  * Several bugs have been fixed in the expression parsing engine
    and the GUI.
  * Fallback to default separator if a separator equals the decimal
    point.
  * Changed default background color.
  * Add Turkish translation.
- Correct License tag: GPL-2.0 -> GPL-2.0+.
- Use full URL as a source.
- Correct build dependencies (remove doxygen, fdupes, gcc, gcc-c++,
  libglade2-devel, make; gtk2-devel -> pkgconfig(gtk+-2.0).
- Split off language subpackage.
- Use %%make_install macro.
- Remove check for unsupported openSUSE versions.
- Remove %%clean section.
- Install docs.
- Clean up spec.
* Mon Nov 19 2012 andrea@opensuse.org
- new upstream version 2.0.1
  * added missing GUI element in preferences dialog (migrated
    GtkOptionMenu to GtkComboBox in Numbers tab)
  * fixed integer parsing rule in flex parser (thanks to John Williams,
    fixes sf.net #74)
  * working around bug with window resizing, I assume this was GTK's
    fault (general_functions.c, set_window_size_minimal)
  * removed deprecated calls to set color on color buttons
  * fixed decimal separator on keypad (thanks to cyberpatrol and
    qwertypoke, fixes sf.net #86)
  * config file stored according to XDG spec (thanks to Eric Heintzmann,
    fixes sf.net #88)
  * applied patch to update spec file for RPM (thanks to Dwigth Engen)
* Tue Oct 16 2012 andrea@opensuse.org
- new upstream version 2.0 (added gtk3 support)
- added flex to build requires
- removed gcalculator-ld_fix.diff
* Sat Oct  1 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Sat Sep 17 2011 suse-tux@gmx.de
- added Patch0 (gcalculator-ld_fix.diff) to fix the build for factory
  (this patch requires a autoreconf call)
* Sun Jul 31 2011 andrea@opensuse.org
- fixed URL
- use more macros where possible
* Mon Mar 14 2011 gber@opensuse.org
- call %%desktop_database_post/un
* Sun Nov 29 2009 andrea@opensuse.org
- New package
